from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from aruna.api.storage.services.v1 import object_service_pb2 as _object_service_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
LOCATION_TYPE_FILE: LocationType
LOCATION_TYPE_S3: LocationType
LOCATION_TYPE_UNSPECIFIED: LocationType

class DeleteObjectRequest(_message.Message):
    __slots__ = ["location"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    location: Location
    def __init__(self, location: _Optional[_Union[Location, _Mapping]] = ...) -> None: ...

class DeleteObjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FinalizeObjectRequest(_message.Message):
    __slots__ = ["collection_id", "content_length", "hashes", "location", "object_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_LENGTH_FIELD_NUMBER: _ClassVar[int]
    HASHES_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    content_length: int
    hashes: _containers.RepeatedCompositeFieldContainer[_models_pb2.Hash]
    location: Location
    object_id: str
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., location: _Optional[_Union[Location, _Mapping]] = ..., hashes: _Optional[_Iterable[_Union[_models_pb2.Hash, _Mapping]]] = ..., content_length: _Optional[int] = ...) -> None: ...

class FinalizeObjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FinishMultipartUploadRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "part_etags", "path", "upload_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PART_ETAGS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    part_etags: _containers.RepeatedCompositeFieldContainer[PartETag]
    path: str
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., path: _Optional[str] = ..., object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., part_etags: _Optional[_Iterable[_Union[PartETag, _Mapping]]] = ...) -> None: ...

class FinishMultipartUploadResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetCollectionByBucketRequest(_message.Message):
    __slots__ = ["access_key", "bucket"]
    ACCESS_KEY_FIELD_NUMBER: _ClassVar[int]
    BUCKET_FIELD_NUMBER: _ClassVar[int]
    access_key: str
    bucket: str
    def __init__(self, bucket: _Optional[str] = ..., access_key: _Optional[str] = ...) -> None: ...

class GetCollectionByBucketResponse(_message.Message):
    __slots__ = ["collection_id", "project_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class GetObjectLocationRequest(_message.Message):
    __slots__ = ["access_key", "endpoint_id", "path", "revision_id"]
    ACCESS_KEY_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    REVISION_ID_FIELD_NUMBER: _ClassVar[int]
    access_key: str
    endpoint_id: str
    path: str
    revision_id: str
    def __init__(self, path: _Optional[str] = ..., revision_id: _Optional[str] = ..., access_key: _Optional[str] = ..., endpoint_id: _Optional[str] = ...) -> None: ...

class GetObjectLocationResponse(_message.Message):
    __slots__ = ["location", "object"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    location: Location
    object: _models_pb2.Object
    def __init__(self, object: _Optional[_Union[_models_pb2.Object, _Mapping]] = ..., location: _Optional[_Union[Location, _Mapping]] = ...) -> None: ...

class GetOrCreateEncryptionKeyRequest(_message.Message):
    __slots__ = ["endpoint_id", "hash", "path"]
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    endpoint_id: str
    hash: str
    path: str
    def __init__(self, path: _Optional[str] = ..., hash: _Optional[str] = ..., endpoint_id: _Optional[str] = ...) -> None: ...

class GetOrCreateEncryptionKeyResponse(_message.Message):
    __slots__ = ["created", "encryption_key"]
    CREATED_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_KEY_FIELD_NUMBER: _ClassVar[int]
    created: bool
    encryption_key: str
    def __init__(self, encryption_key: _Optional[str] = ..., created: bool = ...) -> None: ...

class GetOrCreateObjectByPathRequest(_message.Message):
    __slots__ = ["access_key", "endpoint_id", "get_only", "object", "path"]
    ACCESS_KEY_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    GET_ONLY_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    access_key: str
    endpoint_id: str
    get_only: bool
    object: _object_service_pb2.StageObject
    path: str
    def __init__(self, path: _Optional[str] = ..., access_key: _Optional[str] = ..., object: _Optional[_Union[_object_service_pb2.StageObject, _Mapping]] = ..., get_only: bool = ..., endpoint_id: _Optional[str] = ...) -> None: ...

class GetOrCreateObjectByPathResponse(_message.Message):
    __slots__ = ["collection_id", "created", "dataclass", "hashes", "object_id", "revision_number"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_FIELD_NUMBER: _ClassVar[int]
    DATACLASS_FIELD_NUMBER: _ClassVar[int]
    HASHES_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    created: bool
    dataclass: _models_pb2.DataClass
    hashes: _containers.RepeatedCompositeFieldContainer[_models_pb2.Hash]
    object_id: str
    revision_number: int
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., dataclass: _Optional[_Union[_models_pb2.DataClass, str]] = ..., hashes: _Optional[_Iterable[_Union[_models_pb2.Hash, _Mapping]]] = ..., revision_number: _Optional[int] = ..., created: bool = ...) -> None: ...

class InitMultipartUploadRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "path"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    path: str
    def __init__(self, path: _Optional[str] = ..., object_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class InitMultipartUploadResponse(_message.Message):
    __slots__ = ["upload_id"]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ...) -> None: ...

class Location(_message.Message):
    __slots__ = ["bucket", "encryption_key", "endpoint_id", "is_compressed", "is_encrypted", "path", "type"]
    BUCKET_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_KEY_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    IS_COMPRESSED_FIELD_NUMBER: _ClassVar[int]
    IS_ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    bucket: str
    encryption_key: str
    endpoint_id: str
    is_compressed: bool
    is_encrypted: bool
    path: str
    type: LocationType
    def __init__(self, type: _Optional[_Union[LocationType, str]] = ..., bucket: _Optional[str] = ..., path: _Optional[str] = ..., endpoint_id: _Optional[str] = ..., is_compressed: bool = ..., is_encrypted: bool = ..., encryption_key: _Optional[str] = ...) -> None: ...

class PartETag(_message.Message):
    __slots__ = ["etag", "part_number"]
    ETAG_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    etag: str
    part_number: int
    def __init__(self, part_number: _Optional[int] = ..., etag: _Optional[str] = ...) -> None: ...

class LocationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from aruna.api.storage.models.v1 import query_pb2 as _query_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddLabelsToObjectGroupRequest(_message.Message):
    __slots__ = ["collection_id", "group_id", "labels_to_add"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_TO_ADD_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    group_id: str
    labels_to_add: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    def __init__(self, collection_id: _Optional[str] = ..., group_id: _Optional[str] = ..., labels_to_add: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ...) -> None: ...

class AddLabelsToObjectGroupResponse(_message.Message):
    __slots__ = ["object_group"]
    OBJECT_GROUP_FIELD_NUMBER: _ClassVar[int]
    object_group: _models_pb2.ObjectGroupOverview
    def __init__(self, object_group: _Optional[_Union[_models_pb2.ObjectGroupOverview, _Mapping]] = ...) -> None: ...

class CreateObjectGroupRequest(_message.Message):
    __slots__ = ["collection_id", "description", "hooks", "labels", "meta_object_ids", "name", "object_ids"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    META_OBJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    labels: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    meta_object_ids: _containers.RepeatedScalarFieldContainer[str]
    name: str
    object_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., collection_id: _Optional[str] = ..., object_ids: _Optional[_Iterable[str]] = ..., meta_object_ids: _Optional[_Iterable[str]] = ..., labels: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ...) -> None: ...

class CreateObjectGroupResponse(_message.Message):
    __slots__ = ["object_group"]
    OBJECT_GROUP_FIELD_NUMBER: _ClassVar[int]
    object_group: _models_pb2.ObjectGroupOverview
    def __init__(self, object_group: _Optional[_Union[_models_pb2.ObjectGroupOverview, _Mapping]] = ...) -> None: ...

class DeleteObjectGroupRequest(_message.Message):
    __slots__ = ["collection_id", "group_id", "with_revisions"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    WITH_REVISIONS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    group_id: str
    with_revisions: bool
    def __init__(self, group_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., with_revisions: bool = ...) -> None: ...

class DeleteObjectGroupResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetObjectGroupByIdRequest(_message.Message):
    __slots__ = ["collection_id", "group_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    group_id: str
    def __init__(self, group_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class GetObjectGroupByIdResponse(_message.Message):
    __slots__ = ["object_group"]
    OBJECT_GROUP_FIELD_NUMBER: _ClassVar[int]
    object_group: _models_pb2.ObjectGroupOverview
    def __init__(self, object_group: _Optional[_Union[_models_pb2.ObjectGroupOverview, _Mapping]] = ...) -> None: ...

class GetObjectGroupHistoryRequest(_message.Message):
    __slots__ = ["collection_id", "group_id", "page_request"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    group_id: str
    page_request: _query_pb2.PageRequest
    def __init__(self, collection_id: _Optional[str] = ..., group_id: _Optional[str] = ..., page_request: _Optional[_Union[_query_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class GetObjectGroupHistoryResponse(_message.Message):
    __slots__ = ["object_groups"]
    OBJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    object_groups: _models_pb2.ObjectGroupOverviews
    def __init__(self, object_groups: _Optional[_Union[_models_pb2.ObjectGroupOverviews, _Mapping]] = ...) -> None: ...

class GetObjectGroupObjectsRequest(_message.Message):
    __slots__ = ["collection_id", "group_id", "meta_only", "page_request"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    META_ONLY_FIELD_NUMBER: _ClassVar[int]
    PAGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    group_id: str
    meta_only: bool
    page_request: _query_pb2.PageRequest
    def __init__(self, collection_id: _Optional[str] = ..., group_id: _Optional[str] = ..., page_request: _Optional[_Union[_query_pb2.PageRequest, _Mapping]] = ..., meta_only: bool = ...) -> None: ...

class GetObjectGroupObjectsResponse(_message.Message):
    __slots__ = ["object_group_objects"]
    OBJECT_GROUP_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    object_group_objects: _containers.RepeatedCompositeFieldContainer[ObjectGroupObject]
    def __init__(self, object_group_objects: _Optional[_Iterable[_Union[ObjectGroupObject, _Mapping]]] = ...) -> None: ...

class GetObjectGroupsFromObjectRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "page_request"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    page_request: _query_pb2.PageRequest
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., page_request: _Optional[_Union[_query_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class GetObjectGroupsFromObjectResponse(_message.Message):
    __slots__ = ["object_groups"]
    OBJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    object_groups: _models_pb2.ObjectGroupOverviews
    def __init__(self, object_groups: _Optional[_Union[_models_pb2.ObjectGroupOverviews, _Mapping]] = ...) -> None: ...

class GetObjectGroupsRequest(_message.Message):
    __slots__ = ["collection_id", "label_id_filter", "page_request"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    LABEL_ID_FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    label_id_filter: _query_pb2.LabelOrIDQuery
    page_request: _query_pb2.PageRequest
    def __init__(self, collection_id: _Optional[str] = ..., page_request: _Optional[_Union[_query_pb2.PageRequest, _Mapping]] = ..., label_id_filter: _Optional[_Union[_query_pb2.LabelOrIDQuery, _Mapping]] = ...) -> None: ...

class GetObjectGroupsResponse(_message.Message):
    __slots__ = ["object_groups"]
    OBJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    object_groups: _models_pb2.ObjectGroupOverviews
    def __init__(self, object_groups: _Optional[_Union[_models_pb2.ObjectGroupOverviews, _Mapping]] = ...) -> None: ...

class ObjectGroupObject(_message.Message):
    __slots__ = ["is_metadata", "object"]
    IS_METADATA_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    is_metadata: bool
    object: _models_pb2.Object
    def __init__(self, object: _Optional[_Union[_models_pb2.Object, _Mapping]] = ..., is_metadata: bool = ...) -> None: ...

class UpdateObjectGroupRequest(_message.Message):
    __slots__ = ["collection_id", "description", "group_id", "hooks", "labels", "meta_object_ids", "name", "object_ids"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    META_OBJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    description: str
    group_id: str
    hooks: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    labels: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    meta_object_ids: _containers.RepeatedScalarFieldContainer[str]
    name: str
    object_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, group_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., collection_id: _Optional[str] = ..., object_ids: _Optional[_Iterable[str]] = ..., meta_object_ids: _Optional[_Iterable[str]] = ..., labels: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ...) -> None: ...

class UpdateObjectGroupResponse(_message.Message):
    __slots__ = ["object_group"]
    OBJECT_GROUP_FIELD_NUMBER: _ClassVar[int]
    object_group: _models_pb2.ObjectGroupOverview
    def __init__(self, object_group: _Optional[_Union[_models_pb2.ObjectGroupOverview, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import collection_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2


class CollectionServiceStub(object):
    """CollectionService

    Contains all methods that get/create or update Collection and associated resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNewCollection = channel.unary_unary(
                '/aruna.api.storage.services.v1.CollectionService/CreateNewCollection',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.CreateNewCollectionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.CreateNewCollectionResponse.FromString,
                )
        self.GetCollectionByID = channel.unary_unary(
                '/aruna.api.storage.services.v1.CollectionService/GetCollectionByID',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionByIDRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionByIDResponse.FromString,
                )
        self.GetCollections = channel.unary_unary(
                '/aruna.api.storage.services.v1.CollectionService/GetCollections',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionsResponse.FromString,
                )
        self.UpdateCollection = channel.unary_unary(
                '/aruna.api.storage.services.v1.CollectionService/UpdateCollection',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.UpdateCollectionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.UpdateCollectionResponse.FromString,
                )
        self.PinCollectionVersion = channel.unary_unary(
                '/aruna.api.storage.services.v1.CollectionService/PinCollectionVersion',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.PinCollectionVersionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.PinCollectionVersionResponse.FromString,
                )
        self.DeleteCollection = channel.unary_unary(
                '/aruna.api.storage.services.v1.CollectionService/DeleteCollection',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.DeleteCollectionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.DeleteCollectionResponse.FromString,
                )


class CollectionServiceServicer(object):
    """CollectionService

    Contains all methods that get/create or update Collection and associated resources
    """

    def CreateNewCollection(self, request, context):
        """CreateNewCollection

        Status: STABLE

        creates a new Collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollectionByID(self, request, context):
        """GetCollectionByID

        Status: STABLE

        Queries a specific Collection by ID
        The result can be one_of:
        CollectionOverview -> default
        CollectionWithID
        Collection (full)
        This can be modified with the optional OutputFormat parameter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollections(self, request, context):
        """GetCollections

        Status: STABLE

        queries multiple collections by ID or by LabelFilter
        This returns by default a paginated result with 20 entries.
        Must specify a project_id as context
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCollection(self, request, context):
        """UpdateCollection

        Status: STABLE

        Updates the current collection
        This will update the collection in place if it is unversioned / latest
        A versioned (pinned) collection requires a new semantic version after the
        update This can be used to pin a collection to a specific version similar
        to the PinCollectionVersion request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PinCollectionVersion(self, request, context):
        """PinCollectionVersion

        Status: STABLE

        This pins the current status of the version to a
        specific version. Effectively creating a copy of the collection with a
        stable version All objects will be pinned to an explicit revision number
        Pinned collections can not be updated in place
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCollection(self, request, context):
        """DeleteCollection

        Status: STABLE

        This request deletes the collection.
        If with_version is true, it deletes the collection and all its versions.
        If cascade is true, all objects that are owned by the collection will also
        deleted. This should be avoided
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CollectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNewCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNewCollection,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.CreateNewCollectionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.CreateNewCollectionResponse.SerializeToString,
            ),
            'GetCollectionByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollectionByID,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionByIDRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionByIDResponse.SerializeToString,
            ),
            'GetCollections': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollections,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionsResponse.SerializeToString,
            ),
            'UpdateCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCollection,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.UpdateCollectionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.UpdateCollectionResponse.SerializeToString,
            ),
            'PinCollectionVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.PinCollectionVersion,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.PinCollectionVersionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.PinCollectionVersionResponse.SerializeToString,
            ),
            'DeleteCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCollection,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.DeleteCollectionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.DeleteCollectionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.CollectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CollectionService(object):
    """CollectionService

    Contains all methods that get/create or update Collection and associated resources
    """

    @staticmethod
    def CreateNewCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.CollectionService/CreateNewCollection',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.CreateNewCollectionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.CreateNewCollectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollectionByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.CollectionService/GetCollectionByID',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionByIDRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.CollectionService/GetCollections',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.GetCollectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.CollectionService/UpdateCollection',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.UpdateCollectionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.UpdateCollectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PinCollectionVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.CollectionService/PinCollectionVersion',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.PinCollectionVersionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.PinCollectionVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.CollectionService/DeleteCollection',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.DeleteCollectionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_collection__service__pb2.DeleteCollectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import endpoint_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2


class EndpointServiceStub(object):
    """EndpointService

    Contains all methods that get/create or update Endpoint and associated resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddEndpoint = channel.unary_unary(
                '/aruna.api.storage.services.v1.EndpointService/AddEndpoint',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.AddEndpointRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.AddEndpointResponse.FromString,
                )
        self.GetEndpoint = channel.unary_unary(
                '/aruna.api.storage.services.v1.EndpointService/GetEndpoint',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointResponse.FromString,
                )
        self.GetEndpoints = channel.unary_unary(
                '/aruna.api.storage.services.v1.EndpointService/GetEndpoints',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointsResponse.FromString,
                )
        self.DeleteEndpoint = channel.unary_unary(
                '/aruna.api.storage.services.v1.EndpointService/DeleteEndpoint',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.DeleteEndpointRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.DeleteEndpointResponse.FromString,
                )
        self.GetDefaultEndpoint = channel.unary_unary(
                '/aruna.api.storage.services.v1.EndpointService/GetDefaultEndpoint',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetDefaultEndpointRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetDefaultEndpointResponse.FromString,
                )


class EndpointServiceServicer(object):
    """EndpointService

    Contains all methods that get/create or update Endpoint and associated resources
    """

    def AddEndpoint(self, request, context):
        """AddEndpoint

        Status: BETA

        Registers a new Endpoint (Aruna DataProxy) to the server
        Needs admin permissions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEndpoint(self, request, context):
        """GetEndpoint

        Status: BETA

        Gets an specific endpoint by ID or Name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEndpoints(self, request, context):
        """GetEndpoints

        Status: BETA

        Gets all available endpoints
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEndpoint(self, request, context):
        """DeleteEndpoint

        Status: BETA

        Deletes a specific endpoint by id
        This needs admin permissions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDefaultEndpoint(self, request, context):
        """GetDefaultEndpoint

        Status: BETA

        This request returns the default endpoint for the current aruna_server
        It may produce different results depending on the used server
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EndpointServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.AddEndpoint,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.AddEndpointRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.AddEndpointResponse.SerializeToString,
            ),
            'GetEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEndpoint,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointResponse.SerializeToString,
            ),
            'GetEndpoints': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEndpoints,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointsResponse.SerializeToString,
            ),
            'DeleteEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEndpoint,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.DeleteEndpointRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.DeleteEndpointResponse.SerializeToString,
            ),
            'GetDefaultEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDefaultEndpoint,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetDefaultEndpointRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetDefaultEndpointResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.EndpointService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EndpointService(object):
    """EndpointService

    Contains all methods that get/create or update Endpoint and associated resources
    """

    @staticmethod
    def AddEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.EndpointService/AddEndpoint',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.AddEndpointRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.AddEndpointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.EndpointService/GetEndpoint',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEndpoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.EndpointService/GetEndpoints',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetEndpointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.EndpointService/DeleteEndpoint',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.DeleteEndpointRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.DeleteEndpointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDefaultEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.EndpointService/GetDefaultEndpoint',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetDefaultEndpointRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_endpoint__service__pb2.GetDefaultEndpointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/project_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import auth_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_auth__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3aruna/api/storage/services/v1/project_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a&aruna/api/storage/models/v1/auth.proto\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"L\n\x14\x43reateProjectRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"6\n\x15\x43reateProjectResponse\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"\x91\x01\n\x17\x41\x64\x64UserToProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12W\n\x0fuser_permission\x18\x03 \x01(\x0b\x32..aruna.api.storage.models.v1.ProjectPermissionR\x0euserPermission\"\x1a\n\x18\x41\x64\x64UserToProjectResponse\"2\n\x11GetProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"\\\n\x12GetProjectResponse\x12\x46\n\x07project\x18\x01 \x01(\x0b\x32,.aruna.api.storage.models.v1.ProjectOverviewR\x07project\"\x14\n\x12GetProjectsRequest\"_\n\x13GetProjectsResponse\x12H\n\x08projects\x18\x01 \x03(\x0b\x32,.aruna.api.storage.models.v1.ProjectOverviewR\x08projects\"6\n\x15\x44\x65stroyProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"\x18\n\x16\x44\x65stroyProjectResponse\"k\n\x14UpdateProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"_\n\x15UpdateProjectResponse\x12\x46\n\x07project\x18\x01 \x01(\x0b\x32,.aruna.api.storage.models.v1.ProjectOverviewR\x07project\"V\n\x1cRemoveUserFromProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\"\x1f\n\x1dRemoveUserFromProjectResponse\"]\n#GetUserPermissionsForProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\"\x8a\x01\n$GetUserPermissionsForProjectResponse\x12\x62\n\x0fuser_permission\x18\x01 \x01(\x0b\x32\x39.aruna.api.storage.models.v1.ProjectPermissionDisplayNameR\x0euserPermission\"\x9e\x01\n$EditUserPermissionsForProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12W\n\x0fuser_permission\x18\x02 \x01(\x0b\x32..aruna.api.storage.models.v1.ProjectPermissionR\x0euserPermission\"\'\n%EditUserPermissionsForProjectResponse\"\xae\x01\n\x1aUserWithProjectPermissions\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.aruna.api.storage.models.v1.UserR\x04user\x12Y\n\x10user_permissions\x18\x02 \x01(\x0b\x32..aruna.api.storage.models.v1.ProjectPermissionR\x0fuserPermissions\"G\n&GetAllUserPermissionsForProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"z\n\'GetAllUserPermissionsForProjectResponse\x12O\n\x05users\x18\x01 \x03(\x0b\x32\x39.aruna.api.storage.services.v1.UserWithProjectPermissionsR\x05users2\x90\x0e\n\x0eProjectService\x12\x92\x01\n\rCreateProject\x12\x33.aruna.api.storage.services.v1.CreateProjectRequest\x1a\x34.aruna.api.storage.services.v1.CreateProjectResponse\"\x16\x82\xd3\xe4\x93\x02\x10:\x01*\"\x0b/v1/project\x12\xb1\x01\n\x10\x41\x64\x64UserToProject\x12\x36.aruna.api.storage.services.v1.AddUserToProjectRequest\x1a\x37.aruna.api.storage.services.v1.AddUserToProjectResponse\",\x82\xd3\xe4\x93\x02&:\x01*\"!/v1/project/{project_id}/add_user\x12\x93\x01\n\nGetProject\x12\x30.aruna.api.storage.services.v1.GetProjectRequest\x1a\x31.aruna.api.storage.services.v1.GetProjectResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/project/{project_id}\x12\x8a\x01\n\x0bGetProjects\x12\x31.aruna.api.storage.services.v1.GetProjectsRequest\x1a\x32.aruna.api.storage.services.v1.GetProjectsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/projects\x12\x9f\x01\n\x0e\x44\x65stroyProject\x12\x34.aruna.api.storage.services.v1.DestroyProjectRequest\x1a\x35.aruna.api.storage.services.v1.DestroyProjectResponse\" \x82\xd3\xe4\x93\x02\x1a*\x18/v1/project/{project_id}\x12\x9c\x01\n\rUpdateProject\x12\x33.aruna.api.storage.services.v1.UpdateProjectRequest\x1a\x34.aruna.api.storage.services.v1.UpdateProjectResponse\" \x82\xd3\xe4\x93\x02\x1a\x1a\x18/v1/project/{project_id}\x12\xc0\x01\n\x15RemoveUserFromProject\x12;.aruna.api.storage.services.v1.RemoveUserFromProjectRequest\x1a<.aruna.api.storage.services.v1.RemoveUserFromProjectResponse\",\x82\xd3\xe4\x93\x02&*$/v1/project/{project_id}/remove_user\x12\xd2\x01\n\x1cGetUserPermissionsForProject\x12\x42.aruna.api.storage.services.v1.GetUserPermissionsForProjectRequest\x1a\x43.aruna.api.storage.services.v1.GetUserPermissionsForProjectResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/project/{project_id}/get_user\x12\xdc\x01\n\x1fGetAllUserPermissionsForProject\x12\x45.aruna.api.storage.services.v1.GetAllUserPermissionsForProjectRequest\x1a\x46.aruna.api.storage.services.v1.GetAllUserPermissionsForProjectResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/project/{project_id}/get_users\x12\xd9\x01\n\x1d\x45\x64itUserPermissionsForProject\x12\x43.aruna.api.storage.services.v1.EditUserPermissionsForProjectRequest\x1a\x44.aruna.api.storage.services.v1.EditUserPermissionsForProjectResponse\"-\x82\xd3\xe4\x93\x02\':\x01*2\"/v1/project/{project_id}/edit_userB\xe6\x02\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x0eProjectServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1\x92\x41\xd2\x01\x12\x32\n#Aruna Object Storage (AOS) REST API2\x0b\x31.0.0-rc.15*\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonZ`\n^\n\rAccessKeyAuth\x12M\x08\x02\x12\x38\x41uthentication token, prefixed by Bearer: Bearer <token>\x1a\rAuthorization \x02\x62\x13\n\x11\n\rAccessKeyAuth\x12\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.project_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\016ProjectServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1\222A\322\001\0222\n#Aruna Object Storage (AOS) REST API2\0131.0.0-rc.15*\001\0022\020application/json:\020application/jsonZ`\n^\n\rAccessKeyAuth\022M\010\002\0228Authentication token, prefixed by Bearer: Bearer <token>\032\rAuthorization \002b\023\n\021\n\rAccessKeyAuth\022\000'
  _PROJECTSERVICE.methods_by_name['CreateProject']._options = None
  _PROJECTSERVICE.methods_by_name['CreateProject']._serialized_options = b'\202\323\344\223\002\020:\001*\"\013/v1/project'
  _PROJECTSERVICE.methods_by_name['AddUserToProject']._options = None
  _PROJECTSERVICE.methods_by_name['AddUserToProject']._serialized_options = b'\202\323\344\223\002&:\001*\"!/v1/project/{project_id}/add_user'
  _PROJECTSERVICE.methods_by_name['GetProject']._options = None
  _PROJECTSERVICE.methods_by_name['GetProject']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/project/{project_id}'
  _PROJECTSERVICE.methods_by_name['GetProjects']._options = None
  _PROJECTSERVICE.methods_by_name['GetProjects']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/projects'
  _PROJECTSERVICE.methods_by_name['DestroyProject']._options = None
  _PROJECTSERVICE.methods_by_name['DestroyProject']._serialized_options = b'\202\323\344\223\002\032*\030/v1/project/{project_id}'
  _PROJECTSERVICE.methods_by_name['UpdateProject']._options = None
  _PROJECTSERVICE.methods_by_name['UpdateProject']._serialized_options = b'\202\323\344\223\002\032\032\030/v1/project/{project_id}'
  _PROJECTSERVICE.methods_by_name['RemoveUserFromProject']._options = None
  _PROJECTSERVICE.methods_by_name['RemoveUserFromProject']._serialized_options = b'\202\323\344\223\002&*$/v1/project/{project_id}/remove_user'
  _PROJECTSERVICE.methods_by_name['GetUserPermissionsForProject']._options = None
  _PROJECTSERVICE.methods_by_name['GetUserPermissionsForProject']._serialized_options = b'\202\323\344\223\002#\022!/v1/project/{project_id}/get_user'
  _PROJECTSERVICE.methods_by_name['GetAllUserPermissionsForProject']._options = None
  _PROJECTSERVICE.methods_by_name['GetAllUserPermissionsForProject']._serialized_options = b'\202\323\344\223\002$\022\"/v1/project/{project_id}/get_users'
  _PROJECTSERVICE.methods_by_name['EditUserPermissionsForProject']._options = None
  _PROJECTSERVICE.methods_by_name['EditUserPermissionsForProject']._serialized_options = b'\202\323\344\223\002\':\001*2\"/v1/project/{project_id}/edit_user'
  _CREATEPROJECTREQUEST._serialized_start=204
  _CREATEPROJECTREQUEST._serialized_end=280
  _CREATEPROJECTRESPONSE._serialized_start=282
  _CREATEPROJECTRESPONSE._serialized_end=336
  _ADDUSERTOPROJECTREQUEST._serialized_start=339
  _ADDUSERTOPROJECTREQUEST._serialized_end=484
  _ADDUSERTOPROJECTRESPONSE._serialized_start=486
  _ADDUSERTOPROJECTRESPONSE._serialized_end=512
  _GETPROJECTREQUEST._serialized_start=514
  _GETPROJECTREQUEST._serialized_end=564
  _GETPROJECTRESPONSE._serialized_start=566
  _GETPROJECTRESPONSE._serialized_end=658
  _GETPROJECTSREQUEST._serialized_start=660
  _GETPROJECTSREQUEST._serialized_end=680
  _GETPROJECTSRESPONSE._serialized_start=682
  _GETPROJECTSRESPONSE._serialized_end=777
  _DESTROYPROJECTREQUEST._serialized_start=779
  _DESTROYPROJECTREQUEST._serialized_end=833
  _DESTROYPROJECTRESPONSE._serialized_start=835
  _DESTROYPROJECTRESPONSE._serialized_end=859
  _UPDATEPROJECTREQUEST._serialized_start=861
  _UPDATEPROJECTREQUEST._serialized_end=968
  _UPDATEPROJECTRESPONSE._serialized_start=970
  _UPDATEPROJECTRESPONSE._serialized_end=1065
  _REMOVEUSERFROMPROJECTREQUEST._serialized_start=1067
  _REMOVEUSERFROMPROJECTREQUEST._serialized_end=1153
  _REMOVEUSERFROMPROJECTRESPONSE._serialized_start=1155
  _REMOVEUSERFROMPROJECTRESPONSE._serialized_end=1186
  _GETUSERPERMISSIONSFORPROJECTREQUEST._serialized_start=1188
  _GETUSERPERMISSIONSFORPROJECTREQUEST._serialized_end=1281
  _GETUSERPERMISSIONSFORPROJECTRESPONSE._serialized_start=1284
  _GETUSERPERMISSIONSFORPROJECTRESPONSE._serialized_end=1422
  _EDITUSERPERMISSIONSFORPROJECTREQUEST._serialized_start=1425
  _EDITUSERPERMISSIONSFORPROJECTREQUEST._serialized_end=1583
  _EDITUSERPERMISSIONSFORPROJECTRESPONSE._serialized_start=1585
  _EDITUSERPERMISSIONSFORPROJECTRESPONSE._serialized_end=1624
  _USERWITHPROJECTPERMISSIONS._serialized_start=1627
  _USERWITHPROJECTPERMISSIONS._serialized_end=1801
  _GETALLUSERPERMISSIONSFORPROJECTREQUEST._serialized_start=1803
  _GETALLUSERPERMISSIONSFORPROJECTREQUEST._serialized_end=1874
  _GETALLUSERPERMISSIONSFORPROJECTRESPONSE._serialized_start=1876
  _GETALLUSERPERMISSIONSFORPROJECTRESPONSE._serialized_end=1998
  _PROJECTSERVICE._serialized_start=2001
  _PROJECTSERVICE._serialized_end=3809
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.notification.services.v1 import notification_service_pb2 as aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2


class EventNotificationServiceStub(object):
    """EventNotificationService

    A service to receive events in the AOS storage
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEventStreamingGroup = channel.unary_unary(
                '/aruna.api.notification.services.v1.EventNotificationService/CreateEventStreamingGroup',
                request_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.CreateEventStreamingGroupRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.CreateEventStreamingGroupResponse.FromString,
                )
        self.GetEventMessageBatch = channel.unary_unary(
                '/aruna.api.notification.services.v1.EventNotificationService/GetEventMessageBatch',
                request_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchResponse.FromString,
                )
        self.GetEventMessageBatchStream = channel.unary_stream(
                '/aruna.api.notification.services.v1.EventNotificationService/GetEventMessageBatchStream',
                request_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchStreamRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchStreamResponse.FromString,
                )
        self.AcknowledgeMessageBatch = channel.unary_unary(
                '/aruna.api.notification.services.v1.EventNotificationService/AcknowledgeMessageBatch',
                request_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.AcknowledgeMessageBatchRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.AcknowledgeMessageBatchResponse.FromString,
                )
        self.DeleteEventStreamingGroup = channel.unary_unary(
                '/aruna.api.notification.services.v1.EventNotificationService/DeleteEventStreamingGroup',
                request_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.DeleteEventStreamingGroupRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.DeleteEventStreamingGroupResponse.FromString,
                )


class EventNotificationServiceServicer(object):
    """EventNotificationService

    A service to receive events in the AOS storage
    """

    def CreateEventStreamingGroup(self, request, context):
        """CreateEventStreamingGroup

        Creates a new EventStreamingGroup
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventMessageBatch(self, request, context):
        """GetEventMessageBatch

        Reads a set of messages from a given stream group
        Each message contains a separate acknowledgement message that is protected by a salt and an hmac for verification
        The message can be send directly through the AcknowledgeMessageBatch call to acknowledge the message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventMessageBatchStream(self, request, context):
        """GetEventMessageBatch

        Reads a set of messages from a given stream group
        Each message contains a separate acknowledgement message that is protected by a salt and an hmac for verification
        The message can be send directly through the AcknowledgeMessageBatch call to acknowledge the message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcknowledgeMessageBatch(self, request, context):
        """AcknowledgeMessageBatch

        List of messages to acknowledge
        Each reply is protected by a salt and and hmac that verifies the message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEventStreamingGroup(self, request, context):
        """DeleteEventStreamingGroup

        Deletes a existing EventStreamingGroup by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEventStreamingGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEventStreamingGroup,
                    request_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.CreateEventStreamingGroupRequest.FromString,
                    response_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.CreateEventStreamingGroupResponse.SerializeToString,
            ),
            'GetEventMessageBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEventMessageBatch,
                    request_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchRequest.FromString,
                    response_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchResponse.SerializeToString,
            ),
            'GetEventMessageBatchStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetEventMessageBatchStream,
                    request_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchStreamRequest.FromString,
                    response_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchStreamResponse.SerializeToString,
            ),
            'AcknowledgeMessageBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.AcknowledgeMessageBatch,
                    request_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.AcknowledgeMessageBatchRequest.FromString,
                    response_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.AcknowledgeMessageBatchResponse.SerializeToString,
            ),
            'DeleteEventStreamingGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEventStreamingGroup,
                    request_deserializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.DeleteEventStreamingGroupRequest.FromString,
                    response_serializer=aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.DeleteEventStreamingGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.notification.services.v1.EventNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventNotificationService(object):
    """EventNotificationService

    A service to receive events in the AOS storage
    """

    @staticmethod
    def CreateEventStreamingGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.notification.services.v1.EventNotificationService/CreateEventStreamingGroup',
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.CreateEventStreamingGroupRequest.SerializeToString,
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.CreateEventStreamingGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventMessageBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.notification.services.v1.EventNotificationService/GetEventMessageBatch',
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchRequest.SerializeToString,
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventMessageBatchStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/aruna.api.notification.services.v1.EventNotificationService/GetEventMessageBatchStream',
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchStreamRequest.SerializeToString,
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.GetEventMessageBatchStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcknowledgeMessageBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.notification.services.v1.EventNotificationService/AcknowledgeMessageBatch',
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.AcknowledgeMessageBatchRequest.SerializeToString,
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.AcknowledgeMessageBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEventStreamingGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.notification.services.v1.EventNotificationService/DeleteEventStreamingGroup',
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.DeleteEventStreamingGroupRequest.SerializeToString,
            aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2.DeleteEventStreamingGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import object_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2


class ObjectServiceStub(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitializeNewObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/InitializeNewObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectResponse.FromString,
                )
        self.GetUploadURL = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetUploadURL',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLResponse.FromString,
                )
        self.GetDownloadURL = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetDownloadURL',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLResponse.FromString,
                )
        self.GetDownloadLinksBatch = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetDownloadLinksBatch',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchResponse.FromString,
                )
        self.CreateDownloadLinksStream = channel.unary_stream(
                '/aruna.api.storage.services.v1.ObjectService/CreateDownloadLinksStream',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamResponse.FromString,
                )
        self.FinishObjectStaging = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/FinishObjectStaging',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingResponse.FromString,
                )
        self.UpdateObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/UpdateObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectResponse.FromString,
                )
        self.CreateObjectReference = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/CreateObjectReference',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceResponse.FromString,
                )
        self.CloneObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/CloneObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectResponse.FromString,
                )
        self.DeleteObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/DeleteObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectResponse.FromString,
                )
        self.DeleteObjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/DeleteObjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsResponse.FromString,
                )
        self.GetObjectByID = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectByID',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDResponse.FromString,
                )
        self.GetObjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsResponse.FromString,
                )
        self.GetObjectRevisions = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectRevisions',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsResponse.FromString,
                )
        self.GetLatestObjectRevision = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetLatestObjectRevision',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionResponse.FromString,
                )
        self.GetObjectEndpoints = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectEndpoints',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsResponse.FromString,
                )
        self.AddLabelsToObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/AddLabelsToObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectResponse.FromString,
                )
        self.SetHooksOfObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/SetHooksOfObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectResponse.FromString,
                )
        self.GetReferences = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetReferences',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesResponse.FromString,
                )
        self.GetObjectPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathResponse.FromString,
                )
        self.GetObjectPaths = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectPaths',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsResponse.FromString,
                )
        self.CreateObjectPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/CreateObjectPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathResponse.FromString,
                )
        self.SetObjectPathVisibility = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/SetObjectPathVisibility',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityResponse.FromString,
                )
        self.GetObjectsByPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectsByPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathResponse.FromString,
                )
        self.GetProjectCollectionIdsByPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetProjectCollectionIdsByPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathResponse.FromString,
                )


class ObjectServiceServicer(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resources
    """

    def InitializeNewObject(self, request, context):
        """InitializeNewObject

        Status: STABLE

        This initializes a new object
        Initializing an object will put it in a staging area.
        Staged objects will get a separate staging id and need to be finished
        before they can be used.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUploadURL(self, request, context):
        """GetUploadURL

        Status: STABLE

        This method will return a (multi-part) url that can be used to upload a
        file to S3. Part is a optional query parameter that can be used to upload a
        part of the file / multipart upload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDownloadURL(self, request, context):
        """GetDownloadUrl

        Status: STABLE

        This method will return a url that can be used to download a file from S3.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDownloadLinksBatch(self, request, context):
        """GetDownloadLinksBatch

        Status: BETA

        This method can be used to get download urls for multiple objects.
        The order of the returned urls will be the same as the order of the object
        ids in the request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDownloadLinksStream(self, request, context):
        """CreateDownloadLinksStream

        Status: BETA

        Creates a stream of objects and presigned links based on the provided query
        This can be used retrieve a large number of Objects as a stream that would
        otherwise cause issues with the connection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinishObjectStaging(self, request, context):
        """FinishObjectStaging

        Status: STABLE

        This method completes the staging of an object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateObject(self, request, context):
        """UpdateObject

        Status: STABLE

        Objects are immutable!
        Updating an object will create a new revision for the object
        This method will put the new revision in a staging area.
        Staged objects will get a separate staging id and need to be finished
        before they can be used.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateObjectReference(self, request, context):
        """CreateObjectReference

        Status: STABLE

        Creates a new reference of this object in another collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloneObject(self, request, context):
        """CloneObject 

        Status: STABLE

        This method clones an object and creates a copy in the same collection.
        This copy has a new id and revision and will not receive any updates from
        the original object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteObject(self, request, context):
        """DeleteObject 

        Status: STABLE

        Deletes the object with the complete revision history.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteObjects(self, request, context):
        """DeleteObjects

        Status: STABLE

        Deletes multiple objects at once.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectByID(self, request, context):
        """GetObjectByID 

        Status: STABLE

        gets a specific Object by ID that is associated to the
        current collection By default only the latest revision of an object will be
        returned Specify a revision_number to select an older revision With the
        optional with_url boolean a download link can automatically be requested
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjects(self, request, context):
        """GetObjects

        Status: STABLE

        GetObjects returns a (paginated) list of objects in a specific collection
        By default only the latest revisions of all objects will be shown
        This behaviour can be changed with the include_history flag
        With the optional with_url boolean a download link can automatically be
        requested for each Object This request contains a LabelOrIDQuery message,
        this is either a list of request ObjectIDs or a query filtered by Labels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectRevisions(self, request, context):
        """GetObjectRevisions

        Status: STABLE

        This returns the full list of revisions of a specified object
        With the optional with_url boolean a download link can automatically be
        requested for each Object This is by default a paginated request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestObjectRevision(self, request, context):
        """GetLatestObjectRevision

        Status: STABLE

        This returns the latest revision of a specific object
        The returned `latest` object will have a different id if the current
        object is not the latest revision
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectEndpoints(self, request, context):
        """GetObjectEndpoints

        Status: BETA

        This returns a list of endpoints
        One endpoint will be the "default" endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddLabelsToObject(self, request, context):
        """AddLabelsToObject 

        Status: STABLE

        This is a specific request to add new label(s)
        to an existing object, in contrast to UpdateObject
        this will not create a new object in the staging area
        Instead it will directly add the specified label(s) to the object
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetHooksOfObject(self, request, context):
        """SetHooksOfObject

        Status: BETA

        This is a specific request to update the complete list
        of hooks for a specific object. This will not update the object
        and create a new id, instead it will overwrite all hooks of the existing
        object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReferences(self, request, context):
        """GetReferences

        Status: STABLE

        Get a list of references for this object (optional) including all revisions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectPath(self, request, context):
        """GetObjectPath

        Status: BETA

        Get all object_paths for this object in a specific collection
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectPaths(self, request, context):
        """GetObjectPaths

        Status: BETA

        Get all object_paths for a specific collection
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateObjectPath(self, request, context):
        """CreateObjectPath

        Status: BETA

        Create collection_specific object_paths for an object
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetObjectPathVisibility(self, request, context):
        """SetObjectPathVisibility

        Status: BETA

        Updates the visibility setting for an object_path (hide/unhide)
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectsByPath(self, request, context):
        """GetObjectsByPath

        Status: BETA

        Gets a specific object by object_path
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectCollectionIdsByPath(self, request, context):
        """GetObjectsByPath

        Status: BETA

        Gets a specific object by object_path
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitializeNewObject': grpc.unary_unary_rpc_method_handler(
                    servicer.InitializeNewObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectResponse.SerializeToString,
            ),
            'GetUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUploadURL,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLResponse.SerializeToString,
            ),
            'GetDownloadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDownloadURL,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLResponse.SerializeToString,
            ),
            'GetDownloadLinksBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDownloadLinksBatch,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchResponse.SerializeToString,
            ),
            'CreateDownloadLinksStream': grpc.unary_stream_rpc_method_handler(
                    servicer.CreateDownloadLinksStream,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamResponse.SerializeToString,
            ),
            'FinishObjectStaging': grpc.unary_unary_rpc_method_handler(
                    servicer.FinishObjectStaging,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingResponse.SerializeToString,
            ),
            'UpdateObject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectResponse.SerializeToString,
            ),
            'CreateObjectReference': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateObjectReference,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceResponse.SerializeToString,
            ),
            'CloneObject': grpc.unary_unary_rpc_method_handler(
                    servicer.CloneObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectResponse.SerializeToString,
            ),
            'DeleteObject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectResponse.SerializeToString,
            ),
            'DeleteObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteObjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsResponse.SerializeToString,
            ),
            'GetObjectByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectByID,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDResponse.SerializeToString,
            ),
            'GetObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsResponse.SerializeToString,
            ),
            'GetObjectRevisions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectRevisions,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsResponse.SerializeToString,
            ),
            'GetLatestObjectRevision': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestObjectRevision,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionResponse.SerializeToString,
            ),
            'GetObjectEndpoints': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectEndpoints,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsResponse.SerializeToString,
            ),
            'AddLabelsToObject': grpc.unary_unary_rpc_method_handler(
                    servicer.AddLabelsToObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectResponse.SerializeToString,
            ),
            'SetHooksOfObject': grpc.unary_unary_rpc_method_handler(
                    servicer.SetHooksOfObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectResponse.SerializeToString,
            ),
            'GetReferences': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReferences,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesResponse.SerializeToString,
            ),
            'GetObjectPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathResponse.SerializeToString,
            ),
            'GetObjectPaths': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectPaths,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsResponse.SerializeToString,
            ),
            'CreateObjectPath': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateObjectPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathResponse.SerializeToString,
            ),
            'SetObjectPathVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.SetObjectPathVisibility,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityResponse.SerializeToString,
            ),
            'GetObjectsByPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectsByPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathResponse.SerializeToString,
            ),
            'GetProjectCollectionIdsByPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectCollectionIdsByPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.ObjectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ObjectService(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resources
    """

    @staticmethod
    def InitializeNewObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/InitializeNewObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetUploadURL',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDownloadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetDownloadURL',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDownloadLinksBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetDownloadLinksBatch',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDownloadLinksStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/aruna.api.storage.services.v1.ObjectService/CreateDownloadLinksStream',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinishObjectStaging(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/FinishObjectStaging',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/UpdateObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateObjectReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/CreateObjectReference',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloneObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/CloneObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/DeleteObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/DeleteObjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectByID',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectRevisions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectRevisions',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestObjectRevision(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetLatestObjectRevision',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectEndpoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectEndpoints',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddLabelsToObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/AddLabelsToObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetHooksOfObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/SetHooksOfObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetReferences',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectPaths(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectPaths',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateObjectPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/CreateObjectPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetObjectPathVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/SetObjectPathVisibility',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectsByPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectsByPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectCollectionIdsByPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetProjectCollectionIdsByPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddEndpointRequest(_message.Message):
    __slots__ = ["documentation_path", "ep_type", "internal_hostname", "is_public", "name", "proxy_hostname", "pubkey"]
    DOCUMENTATION_PATH_FIELD_NUMBER: _ClassVar[int]
    EP_TYPE_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROXY_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    PUBKEY_FIELD_NUMBER: _ClassVar[int]
    documentation_path: str
    ep_type: _models_pb2.EndpointType
    internal_hostname: str
    is_public: bool
    name: str
    proxy_hostname: str
    pubkey: str
    def __init__(self, name: _Optional[str] = ..., ep_type: _Optional[_Union[_models_pb2.EndpointType, str]] = ..., proxy_hostname: _Optional[str] = ..., internal_hostname: _Optional[str] = ..., documentation_path: _Optional[str] = ..., is_public: bool = ..., pubkey: _Optional[str] = ...) -> None: ...

class AddEndpointResponse(_message.Message):
    __slots__ = ["endpoint", "pubkey_serial"]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    PUBKEY_SERIAL_FIELD_NUMBER: _ClassVar[int]
    endpoint: _models_pb2.Endpoint
    pubkey_serial: int
    def __init__(self, endpoint: _Optional[_Union[_models_pb2.Endpoint, _Mapping]] = ..., pubkey_serial: _Optional[int] = ...) -> None: ...

class DeleteEndpointRequest(_message.Message):
    __slots__ = ["endpoint_id"]
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    endpoint_id: str
    def __init__(self, endpoint_id: _Optional[str] = ...) -> None: ...

class DeleteEndpointResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDefaultEndpointRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDefaultEndpointResponse(_message.Message):
    __slots__ = ["endpoint"]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    endpoint: _models_pb2.Endpoint
    def __init__(self, endpoint: _Optional[_Union[_models_pb2.Endpoint, _Mapping]] = ...) -> None: ...

class GetEndpointRequest(_message.Message):
    __slots__ = ["endpoint_id", "endpoint_name"]
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_NAME_FIELD_NUMBER: _ClassVar[int]
    endpoint_id: str
    endpoint_name: str
    def __init__(self, endpoint_name: _Optional[str] = ..., endpoint_id: _Optional[str] = ...) -> None: ...

class GetEndpointResponse(_message.Message):
    __slots__ = ["endpoint"]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    endpoint: _models_pb2.Endpoint
    def __init__(self, endpoint: _Optional[_Union[_models_pb2.Endpoint, _Mapping]] = ...) -> None: ...

class GetEndpointsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetEndpointsResponse(_message.Message):
    __slots__ = ["endpoints"]
    ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    endpoints: _containers.RepeatedCompositeFieldContainer[_models_pb2.Endpoint]
    def __init__(self, endpoints: _Optional[_Iterable[_Union[_models_pb2.Endpoint, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/info_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0aruna/api/storage/services/v1/info_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/api/annotations.proto\"\x8e\x01\n\x1bGetResourceHierarchyRequest\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\x12N\n\rresource_type\x18\x02 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x0cresourceType\"\x96\x01\n\tHierarchy\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12(\n\x10object_group_ids\x18\x02 \x03(\tR\x0eobjectGroupIds\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1d\n\nproject_id\x18\x04 \x01(\tR\tprojectId\"j\n\x1cGetResourceHierarchyResponse\x12J\n\x0bhierarchies\x18\x01 \x03(\x0b\x32(.aruna.api.storage.services.v1.HierarchyR\x0bhierarchies\"\x1a\n\x18GetStorageVersionRequest\"\x92\x01\n\x0fSemanticVersion\x12%\n\x0eversion_string\x18\x01 \x01(\tR\rversionString\x12\x14\n\x05major\x18\x02 \x01(\x05R\x05major\x12\x14\n\x05minor\x18\x03 \x01(\x05R\x05minor\x12\x14\n\x05patch\x18\x04 \x01(\x05R\x05patch\x12\x16\n\x06labels\x18\x05 \x01(\tR\x06labels\"w\n\x0fLocationVersion\x12\x1a\n\x08location\x18\x01 \x01(\tR\x08location\x12H\n\x07version\x18\x02 \x01(\x0b\x32..aruna.api.storage.services.v1.SemanticVersionR\x07version\"\x94\x01\n\x10\x43omponentVersion\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12Y\n\x10location_version\x18\x02 \x03(\x0b\x32..aruna.api.storage.services.v1.LocationVersionR\x0flocationVersion\"y\n\x19GetStorageVersionResponse\x12\\\n\x11\x63omponent_version\x18\x01 \x03(\x0b\x32/.aruna.api.storage.services.v1.ComponentVersionR\x10\x63omponentVersion\"\x19\n\x17GetStorageStatusRequest\"k\n\x0eLocationStatus\x12\x1a\n\x08location\x18\x01 \x01(\tR\x08location\x12=\n\x06status\x18\x02 \x01(\x0e\x32%.aruna.api.storage.services.v1.StatusR\x06status\"\x90\x01\n\x0f\x43omponentStatus\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12V\n\x0flocation_status\x18\x02 \x03(\x0b\x32-.aruna.api.storage.services.v1.LocationStatusR\x0elocationStatus\"u\n\x18GetStorageStatusResponse\x12Y\n\x10\x63omponent_status\x18\x01 \x03(\x0b\x32..aruna.api.storage.services.v1.ComponentStatusR\x0f\x63omponentStatus*w\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10STATUS_AVAILABLE\x10\x01\x12\x16\n\x12STATUS_UNAVAILABLE\x10\x02\x12\x13\n\x0fSTATUS_DEGRADED\x10\x03\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x04\x32\xe0\x01\n\x13ResourceInfoService\x12\xb4\x01\n\x14GetResourceHierarchy\x12:.aruna.api.storage.services.v1.GetResourceHierarchyRequest\x1a;.aruna.api.storage.services.v1.GetResourceHierarchyResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/info/resource/hierarchy\x1a\x12\xfa\xd2\xe4\x93\x02\x0c\x12\nUNFINISHED2\xd6\x02\n\x12StorageInfoService\x12\xa0\x01\n\x11GetStorageVersion\x12\x37.aruna.api.storage.services.v1.GetStorageVersionRequest\x1a\x38.aruna.api.storage.services.v1.GetStorageVersionResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/info/version\x12\x9c\x01\n\x10GetStorageStatus\x12\x36.aruna.api.storage.services.v1.GetStorageStatusRequest\x1a\x37.aruna.api.storage.services.v1.GetStorageStatusResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/info/statusB\x8d\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x0bInfoServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.info_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\013InfoServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _RESOURCEINFOSERVICE._options = None
  _RESOURCEINFOSERVICE._serialized_options = b'\372\322\344\223\002\014\022\nUNFINISHED'
  _RESOURCEINFOSERVICE.methods_by_name['GetResourceHierarchy']._options = None
  _RESOURCEINFOSERVICE.methods_by_name['GetResourceHierarchy']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/info/resource/hierarchy'
  _STORAGEINFOSERVICE.methods_by_name['GetStorageVersion']._options = None
  _STORAGEINFOSERVICE.methods_by_name['GetStorageVersion']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/info/version'
  _STORAGEINFOSERVICE.methods_by_name['GetStorageStatus']._options = None
  _STORAGEINFOSERVICE.methods_by_name['GetStorageStatus']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/info/status'
  _STATUS._serialized_start=1564
  _STATUS._serialized_end=1683
  _GETRESOURCEHIERARCHYREQUEST._serialized_start=185
  _GETRESOURCEHIERARCHYREQUEST._serialized_end=327
  _HIERARCHY._serialized_start=330
  _HIERARCHY._serialized_end=480
  _GETRESOURCEHIERARCHYRESPONSE._serialized_start=482
  _GETRESOURCEHIERARCHYRESPONSE._serialized_end=588
  _GETSTORAGEVERSIONREQUEST._serialized_start=590
  _GETSTORAGEVERSIONREQUEST._serialized_end=616
  _SEMANTICVERSION._serialized_start=619
  _SEMANTICVERSION._serialized_end=765
  _LOCATIONVERSION._serialized_start=767
  _LOCATIONVERSION._serialized_end=886
  _COMPONENTVERSION._serialized_start=889
  _COMPONENTVERSION._serialized_end=1037
  _GETSTORAGEVERSIONRESPONSE._serialized_start=1039
  _GETSTORAGEVERSIONRESPONSE._serialized_end=1160
  _GETSTORAGESTATUSREQUEST._serialized_start=1162
  _GETSTORAGESTATUSREQUEST._serialized_end=1187
  _LOCATIONSTATUS._serialized_start=1189
  _LOCATIONSTATUS._serialized_end=1296
  _COMPONENTSTATUS._serialized_start=1299
  _COMPONENTSTATUS._serialized_end=1443
  _GETSTORAGESTATUSRESPONSE._serialized_start=1445
  _GETSTORAGESTATUSRESPONSE._serialized_end=1562
  _RESOURCEINFOSERVICE._serialized_start=1686
  _RESOURCEINFOSERVICE._serialized_end=1910
  _STORAGEINFOSERVICE._serialized_start=1913
  _STORAGEINFOSERVICE._serialized_end=2255
# @@protoc_insertion_point(module_scope)
